<?xml version="1.0" encoding="windows-1252"?>
<xsl:stylesheet 
  version="1.0" 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main" 
  xmlns:ch="http://www.conceptualheaven.com/extract/v10"
  exclude-result-prefixes="w">

<!-- nc = noun concept -->
<!-- ic = individual concept -->
<!-- vc = verb concept -->
<!-- kw = keyword -->
<!-- rf = reference -->
<!-- nostyle = unmarked or no character style -->

<xsl:output method="xml" encoding="UTF-8" omit-xml-declaration="no"/>

<xsl:variable name="upper">ABCDEFGHIJKLMNOPQRSTUVWXYZ </xsl:variable>
<xsl:variable name="lower">abcdefghijklmnopqrstuvwxyz-</xsl:variable>

<xsl:template match="/">
	<ch:vocabulary-document>
		<xsl:apply-templates select="//w:body/w:p[w:pPr/w:pStyle[@w:val='Glossaryentryheader']][w:r]"/>
	</ch:vocabulary-document>
</xsl:template>

<xsl:template match="w:p">
	<ch:gl-entry>			
		<xsl:apply-templates mode="entry" select="w:r"/>						
		<xsl:apply-templates select="following-sibling::*[1][name()='w:tbl']"/>
	</ch:gl-entry>
</xsl:template>

<xsl:template mode="entry" match="w:r">
	<xsl:call-template name="put-styles"/>
</xsl:template>

<xsl:template name="put-styles" match="w:r">
<xsl:variable name="thisval">
	<xsl:choose>
		<xsl:when test="w:rPr">
			<xsl:value-of select="w:rPr/w:rStyle/@w:val"/>			
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>nostyle</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
</xsl:variable>
	<xsl:choose>
		<xsl:when test="normalize-space(w:t)=''">
			<ch:nostyle>
				<xsl:value-of select="w:t"/>
			</ch:nostyle>	
		</xsl:when>
		<xsl:when test="$thisval='Nounconcept'">
			<ch:nc>
				<xsl:value-of select="w:t"/>
			</ch:nc>				
		</xsl:when>
		<xsl:when test="$thisval='Individualconcept'">
			<ch:ic>
				<xsl:value-of select="w:t"/>
			</ch:ic>				
		</xsl:when>	
		<xsl:when test="$thisval='Verbconcept'">
			<ch:vc>
				<xsl:value-of select="w:t"/>
			</ch:vc>				
		</xsl:when>
		<xsl:when test="$thisval='Keyword'">
			<ch:kw>
				<xsl:value-of select="w:t"/>
			</ch:kw>				
		</xsl:when>				
		<xsl:when test="$thisval='Reference'">
			<ch:rf>
				<xsl:value-of select="w:t"/>
			</ch:rf>				
		</xsl:when>	
		<xsl:when test="$thisval='Unmarked'">
			<ch:nostyle>
				<xsl:value-of select="w:t"/>
			</ch:nostyle>				
		</xsl:when>		
		<xsl:when test="$thisval='nostyle'">	
			<ch:nostyle>
				<xsl:value-of select="w:t"/>
			</ch:nostyle>						
		</xsl:when>	
	</xsl:choose>
</xsl:template>

<xsl:template match="w:tbl">
	<ch:details>
		<xsl:apply-templates select="w:tr"/>
	</ch:details>
</xsl:template>

<xsl:template match="w:tr">
<xsl:variable name="source-label">
	<xsl:apply-templates select="w:tc[1]/w:p/w:r/w:t"/>
</xsl:variable>
<xsl:variable name="target-label">
	<xsl:choose>
		<xsl:when test="substring($source-label,string-length($source-label))=':'">
			<xsl:value-of select="substring($source-label,1,string-length($source-label) - 1)"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$source-label"/>			
		</xsl:otherwise>
	</xsl:choose>
</xsl:variable>	
<xsl:variable name="lower-target-label">
	<xsl:value-of select="translate($target-label,$upper,$lower)"/>
</xsl:variable>	
	<xsl:if test="w:tc/w:p/w:r/w:t">
		<ch:detail ch:label="{$lower-target-label}">
			<xsl:choose>
				<xsl:when test="$lower-target-label='synonym'">
					<xsl:apply-templates mode="entry" select="w:tc[2]/w:p/w:r"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates mode="body" select="w:tc[2]/w:p/w:r/w:t"/>
				</xsl:otherwise>
			</xsl:choose>
		</ch:detail>
	</xsl:if>
</xsl:template>

<xsl:template mode="body" match="w:t">	
	<xsl:value-of select="."/>
</xsl:template>

</xsl:stylesheet>
