<?xml version="1.0" encoding="windows-1252"?>
<xsl:stylesheet 
  version="1.0" 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main" 
  xmlns:ch="http://www.conceptualheaven.com/extract/v10"
  exclude-result-prefixes="w">
  
<!-- nc = noun concept -->
<!-- ic = individual concept -->
<!-- vc = verb concept -->
<!-- kw = keyword -->
<!-- rf = reference -->
<!-- nostyle = unmarked or no character style -->

<!-- vcn = verb concept name -->

<xsl:output method="xml" encoding="UTF-8" omit-xml-declaration="no"/>

<xsl:variable name="upper">ABCDEFGHIJKLMNOPQRSTUVWXYZ </xsl:variable>
<xsl:variable name="lower">abcdefghijklmnopqrstuvwxyz-</xsl:variable>
	
<xsl:template match="/">
	<xsl:apply-templates select="ch:vocabulary-document"/>
</xsl:template>

<xsl:template match="ch:vocabulary-document">
<xsl:variable name="ns-uri">
	<xsl:value-of select="ch:gl-entry[1]
		[ch:ic]
		[count(*[name()!='ch:ic' and name()!='ch:details'])=0]
		/ch:details/ch:detail[@ch:label='namespace-uri']"/>
</xsl:variable>
<xsl:variable name="voc-name">
	<xsl:apply-templates select="ch:gl-entry[1]
		[count(*[name()!='ch:ic' and name()!='ch:details'])=0]
		/ch:ic"/>
</xsl:variable>
<xsl:variable name="voc-syn-name">
	<xsl:value-of select="ch:gl-entry[1]
		[ch:ic]
		[count(*[name()!='ch:ic' and name()!='ch:details'])=0]
		/ch:details/ch:detail[@ch:label='synonym']"/>
</xsl:variable>
	<xsl:copy>
		<xsl:attribute name="ch:namespace-uri">
			<xsl:choose>
				<xsl:when test="$ns-uri='http://www.conceptualheaven.com/undefined'">
					<xsl:value-of select="''"/>
				</xsl:when>				
				<xsl:when test="$ns-uri!=''">
					<xsl:value-of select="$ns-uri"/>
				</xsl:when>			
				<xsl:otherwise>
					<xsl:text>http://www.conceptualheaven.com/undefined</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
		<xsl:attribute name="ch:vocabulary-name"><xsl:value-of select="$voc-name"/></xsl:attribute>
		<xsl:attribute name="ch:vocabulary-abbreviation"><xsl:value-of select="$voc-syn-name"/></xsl:attribute>
		<xsl:apply-templates select="ch:gl-entry"/>
	</xsl:copy>
</xsl:template>

<xsl:template match="ch:gl-entry">
	<xsl:copy>
		<xsl:call-template name="put-group">
			<xsl:with-param name="level">entry</xsl:with-param>
		</xsl:call-template>
		<xsl:apply-templates select="ch:details"/>
	</xsl:copy>		
</xsl:template>

<xsl:template name="put-group">
<xsl:param name="level"/>
<xsl:variable name="verbkey">
	<xsl:choose>
		<xsl:when test="$level='entry'">
			<xsl:apply-templates select="*[name()!='ch:details']"/>
		</xsl:when>
		<xsl:when test="$level='detail'">
			<xsl:apply-templates select="."/>
		</xsl:when>		
	</xsl:choose>
</xsl:variable>
	<xsl:choose>
		<xsl:when test="ch:rf
			or	ch:nostyle[normalize-space(.)!='']
			or 	( not(ch:vc) and ch:kw)			
			or	( ch:vc 	and ch:kw
					[		not(preceding-sibling::*[name()!='ch:nostyle'][1][name()='ch:nc'])
						or	(following-sibling::*[name()!='ch:nostyle'][1][name()='ch:nc' or name()='ch:ic'])
					]
				)">
			<ch:undefined>
				<xsl:attribute name="ch:key">
					<xsl:value-of select="normalize-space($verbkey)"/>
				</xsl:attribute>				
			</ch:undefined>
		</xsl:when>
		<xsl:otherwise>
			<xsl:choose>
				<xsl:when test="ch:vc">
					<ch:vcn>
						<xsl:attribute name="ch:key">
							<xsl:value-of select="normalize-space($verbkey)"/>
						</xsl:attribute>
						<xsl:apply-templates mode="group" select="(ch:nc|ch:ic|ch:vc|ch:kw)">
						<xsl:with-param name="nounkey">no</xsl:with-param>
						</xsl:apply-templates>				
					</ch:vcn>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates mode="group" select="(ch:nc|ch:ic)">
						<xsl:with-param name="nounkey">yes</xsl:with-param>
					</xsl:apply-templates>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="ch:details">
	<ch:details>
		<xsl:apply-templates select="ch:detail"/>
	</ch:details>
</xsl:template>

<xsl:template match="ch:detail">
	<xsl:copy>
		<xsl:copy-of select="@ch:label"/>
		<xsl:value-of select="."/>
	</xsl:copy>
</xsl:template>

<xsl:template mode="group" match="*">
<xsl:param name="nounkey" select="'no'"/>
<xsl:variable name="this">
	<xsl:value-of select="name(self::*)"/>
</xsl:variable>
<xsl:variable name="this-pos">
	<xsl:value-of select="count(preceding-sibling::*)"/>
</xsl:variable>
<xsl:variable name="this-group">
	<xsl:apply-templates select="self::*"/>
	<xsl:apply-templates select="following-sibling::*
		[name()=$this or name()='ch:nostyle']
		[not(
			preceding-sibling::*
				[name()!=$this and name()!='ch:nostyle']
				[count(preceding-sibling::*) &gt; $this-pos]
			)
		]"/>
</xsl:variable>
<xsl:if test="not(preceding-sibling::*[name()!='ch:nostyle'][1][name()=$this])">
	<xsl:copy>
	<xsl:if test="$nounkey='yes'">
		<xsl:attribute name="ch:key">
			<xsl:value-of select="normalize-space($this-group)"/>
		</xsl:attribute>		
	</xsl:if>
	<xsl:value-of select="normalize-space($this-group)"/>
	</xsl:copy>
</xsl:if>
</xsl:template>

</xsl:stylesheet>

