<?xml version="1.0" encoding="windows-1252"?>
<xsl:stylesheet 
  version="1.0" 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main" 
  xmlns:ch="http://www.conceptualheaven.com/extract/v10"
  exclude-result-prefixes="w">

<xsl:output method="xml" encoding="UTF-8" omit-xml-declaration="no"/>

<xsl:variable name="upper">ABCDEFGHIJKLMNOPQRSTUVWXYZ </xsl:variable>
<xsl:variable name="lower">abcdefghijklmnopqrstuvwxyz-</xsl:variable>

<xsl:template match="/">
	<ch:validation-messages>
	<xsl:copy-of select="//ch:vocabulary-document/@*"/>
		<xsl:for-each select="ch:vocabulary-document/@ch:namespace-uri[.='']">
			<ch:message>
				<ch:msg-code>
					<xsl:text>VAL-001:</xsl:text>
				</ch:msg-code>
				<ch:msg>
					<xsl:text>
						Error: Namespace URI 'http://www.conceptualheaven.com/undefined' declared for the subject vocabulary is a reserved namespace URI.
					</xsl:text>
				</ch:msg>
			</ch:message>
		</xsl:for-each>
		<xsl:for-each select="ch:vocabulary-document/@ch:namespace-uri[.='http://www.conceptualheaven.com/undefined']">
			<ch:message>
				<ch:msg-code>
					<xsl:text>VAL-002:</xsl:text>
				</ch:msg-code>
				<ch:msg>
					<xsl:text>
						Error: Subject vocabulary not declared, or subject vocabulary has no declared namespace URI.
					</xsl:text>
				</ch:msg>
			</ch:message>		
		</xsl:for-each>
		<xsl:for-each select="//ch:details[count(ch:detail[@ch:label='namespace-uri']) &gt; 1]">
			<ch:message>
				<ch:msg-code>
					<xsl:text>VAL-003:</xsl:text>
				</ch:msg-code>
				<ch:msg>
					<xsl:text>Error: Glossary entry for '</xsl:text>
					<xsl:value-of select="../*[1]/@ch:key"/>
					<xsl:text>' has multiple detail lines labeled "Namespace URI".</xsl:text>	
				</ch:msg>
			</ch:message>			
		</xsl:for-each>
		<xsl:for-each select="//ch:details[ch:detail[@ch:label='namespace-uri']][../*[name()!='ch:ic' and name()!='ch:details']]">
			<ch:message>
				<ch:msg-code>
					<xsl:text>VAL-004:</xsl:text>
				</ch:msg-code>
				<ch:msg>
					<xsl:text>Error: Glossary entry for '</xsl:text>
					<xsl:value-of select="../*[1]/@ch:key"/>
					<xsl:text>' with explanation labeled "Namespace URI" is not for an individual concept.</xsl:text>		
				</ch:msg>
			</ch:message>							
		</xsl:for-each>		
		<xsl:apply-templates mode="val-005" select="/ch:vocabulary-document/ch:gl-entry[*[1][@ch:key]]"/>
		<xsl:apply-templates mode="val-006" select="//ch:vcn/*[name()='ch:nc' or name()='ch:ic']"/>
		<xsl:apply-templates mode="val-007" select="//ch:detail[@ch:label='role-in']"/>		
		<xsl:apply-templates mode="val-008" select="//ch:detail[@ch:label='general-concept']"/>				
		<xsl:apply-templates mode="val-008" select="//ch:detail[@ch:label='more-general-concept']"/>				
		<xsl:apply-templates mode="val-009" select="//ch:detail[@ch:label='synonym']"/>						
		<xsl:apply-templates mode="val-010" select="//ch:detail[@ch:label='synonymous-form']"/>								
		<xsl:apply-templates mode="val-010" select="//ch:detail[@ch:label='syn.-form']"/>								
		<xsl:apply-templates mode="val-010" select="//ch:detail[@ch:label='syn.form']"/>				
		<xsl:apply-templates mode="val-011g" select="//ch:detail[@ch:label='see'][../preceding-sibling::ch:nc[@ch:key]]"/>
		<xsl:apply-templates mode="val-011i" select="//ch:detail[@ch:label='see'][../preceding-sibling::ch:ic[@ch:key]]"/>
		<xsl:apply-templates mode="val-011v" select="//ch:detail[@ch:label='see'][../preceding-sibling::ch:vcn[@ch:key]]"/>
		<xsl:apply-templates mode="val-012" select="//ch:gl-entry/ch:undefined"/>
	</ch:validation-messages>
</xsl:template>

<xsl:template mode="val-005" match="ch:gl-entry">
<xsl:variable name="this" select="*[1]/@ch:key"/>
	<xsl:if test="following-sibling::ch:gl-entry[*[1][@ch:key=$this]]">
		<ch:message>
			<ch:msg-code>
				<xsl:text>VAL-005:</xsl:text>
			</ch:msg-code>
			<ch:msg>
				<xsl:text>Error: More than one glossary entry for concept '</xsl:text>
				<xsl:value-of select="$this"/>
				<xsl:text>'.</xsl:text>	
			</ch:msg>
		</ch:message>									
	</xsl:if>
</xsl:template>

<xsl:template mode="val-006" match="*">
<xsl:variable name="this" select="."/>
<xsl:variable name="this-vcn" select="../@ch:key"/>
	<xsl:if test="not(//ch:gl-entry/*[name()='ch:nc' or name()='ch:ic'][@ch:key=$this])">
		<ch:message>
			<ch:msg-code>
				<xsl:text>VAL-006:</xsl:text>
			</ch:msg-code>
			<ch:msg>
				<xsl:text>Error: Verb concept '</xsl:text>
				<xsl:value-of select="$this-vcn"/>
				<xsl:text>' involves undeclared noun concept '</xsl:text>	
				<xsl:value-of select="$this"/>			
				<xsl:text>'.</xsl:text>
			</ch:msg>
		</ch:message>								
	</xsl:if>
</xsl:template>

<xsl:template mode="val-007" match="ch:detail">
<xsl:variable name="this">
	<xsl:choose>
		<xsl:when test="substring(.,string-length(.))='.'">
			<xsl:value-of select="substring(.,1,string-length(.) - 1)"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="."/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:variable>
<xsl:variable name="this-concept" select="../preceding-sibling::*[1]/@ch:key"/>
	<xsl:if test="not(//ch:vcn[@ch:key=$this])">
		<ch:message>
			<ch:msg-code>
				<xsl:text>VAL-007:</xsl:text>
			</ch:msg-code>
			<ch:msg>
				<xsl:text>Error: Glossary entry for concept '</xsl:text>
				<xsl:value-of select="$this-concept"/>
				<xsl:text>' has explanation labeled "Role in:" with value '</xsl:text>
				<xsl:value-of select="$this"/>
				<xsl:text>', but that verb concept is not declared.</xsl:text>			
			</ch:msg>
		</ch:message>									
	</xsl:if>
</xsl:template>

<xsl:template mode="val-008" match="ch:detail">
<xsl:variable name="this">
	<xsl:choose>
		<xsl:when test="substring(.,string-length(.))='.'">
			<xsl:value-of select="substring(.,1,string-length(.) - 1)"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="."/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:variable>
<xsl:variable name="this-concept" select="../preceding-sibling::*[1]/@ch:key"/>
<xsl:variable name="this-label" select="@ch:label"/>
	<xsl:if test="not(//ch:gl-entry/ch:nc[@ch:key=$this])">
		<ch:message>
			<ch:msg-code>
				<xsl:text>VAL-008:</xsl:text>
			</ch:msg-code>
			<ch:msg>
				<xsl:text>Error: Glossary entry for concept '</xsl:text>
				<xsl:value-of select="$this-concept"/>
				<xsl:text>' has explanation labeled "</xsl:text>
				<xsl:choose>
					<xsl:when test="$this-label='more-general-concept'">
						<xsl:text>More general concept</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>General concept</xsl:text>
					</xsl:otherwise>
				</xsl:choose>			
				<xsl:text>" with value '</xsl:text>		
				<xsl:value-of select="$this"/>		
				<xsl:text>', but that general concept is not declared.</xsl:text>				
			</ch:msg>
		</ch:message>									
	</xsl:if>
</xsl:template>

<xsl:template mode="val-009" match="ch:detail">
<xsl:variable name="this">
	<xsl:choose>
		<xsl:when test="substring(.,string-length(.))='.'">
			<xsl:value-of select="substring(.,1,string-length(.) - 1)"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="."/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:variable>
<xsl:variable name="this-concept" select="../preceding-sibling::*[1]/@ch:key"/>
	<xsl:if test="not(//ch:gl-entry/*[name()='ch:nc' or name()='ch:ic'][@ch:key=$this])">
		<ch:message>
			<ch:msg-code>
				<xsl:text>VAL-009:</xsl:text>
			</ch:msg-code>
			<ch:msg>
				<xsl:text>Error: Glossary entry for concept '</xsl:text>
				<xsl:value-of select="$this-concept"/>
				<xsl:text>' has explanation labeled "Synonym:" with value '</xsl:text>
				<xsl:value-of select="$this"/>
				<xsl:text>', but there is no declared noun concept by that name.</xsl:text>				
			</ch:msg>
		</ch:message>									
	</xsl:if>
</xsl:template>

<xsl:template mode="val-010" match="ch:detail">
<xsl:variable name="this">
	<xsl:choose>
		<xsl:when test="substring(.,string-length(.))='.'">
			<xsl:value-of select="substring(.,1,string-length(.) - 1)"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="."/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:variable>
<xsl:variable name="this-concept" select="../preceding-sibling::*[1]/@ch:key"/>
	<xsl:if test="not(//ch:gl-entry/ch:vcn[@ch:key=$this])">
		<ch:message>
			<ch:msg-code>
				<xsl:text>VAL-010:</xsl:text>
			</ch:msg-code>
			<ch:msg>
				<xsl:text>Error: Glossary entry for concept '</xsl:text>
				<xsl:value-of select="$this-concept"/>
				<xsl:text>' has explanation labeled "Synonymous Form:" or "Syn. Form" with value '</xsl:text>
				<xsl:value-of select="$this"/>
				<xsl:text>', but there is no declared verb concept by that name.</xsl:text>					
			</ch:msg>
		</ch:message>								
	</xsl:if>
</xsl:template>

<xsl:template mode="val-011g" match="ch:detail">
<xsl:variable name="this">
	<xsl:choose>
		<xsl:when test="substring(.,string-length(.))='.'">
			<xsl:value-of select="substring(.,1,string-length(.) - 1)"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="."/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:variable>
<xsl:variable name="this-concept" select="../preceding-sibling::*[1]/@ch:key"/>
	<xsl:if test="not(//ch:gl-entry/ch:nc[@ch:key=$this])">
		<ch:message>
			<ch:msg-code>
				<xsl:text>VAL-011:</xsl:text>
			</ch:msg-code>
			<ch:msg>
				<xsl:text>Error: Glossary entry for general concept '</xsl:text>
				<xsl:value-of select="$this-concept"/>
				<xsl:text>' has explanation labeled "See" with value '</xsl:text>
				<xsl:value-of select="$this"/>
				<xsl:text>', but that general concept is not declared.</xsl:text>					
			</ch:msg>
		</ch:message>									
	</xsl:if>
</xsl:template>

<xsl:template mode="val-011i" match="ch:detail">
<xsl:variable name="this">
	<xsl:choose>
		<xsl:when test="substring(.,string-length(.))='.'">
			<xsl:value-of select="substring(.,1,string-length(.) - 1)"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="."/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:variable>
<xsl:variable name="this-concept" select="../preceding-sibling::*[1]/@ch:key"/>
	<xsl:if test="not(//ch:gl-entry/ch:ic[@ch:key=$this])">
		<ch:message>
			<ch:msg-code>
				<xsl:text>VAL-011:</xsl:text>
			</ch:msg-code>
			<ch:msg>
				<xsl:text>Error: Glossary entry for individual concept '</xsl:text>
				<xsl:value-of select="$this-concept"/>
				<xsl:text>' has explanation labeled "See" with value '</xsl:text>
				<xsl:value-of select="$this"/>
				<xsl:text>', but that individual concept is not declared.</xsl:text>					
			</ch:msg>
		</ch:message>							
	</xsl:if>
</xsl:template>

<xsl:template mode="val-011v" match="ch:detail">
<xsl:variable name="this">
	<xsl:choose>
		<xsl:when test="substring(.,string-length(.))='.'">
			<xsl:value-of select="substring(.,1,string-length(.) - 1)"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="."/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:variable>
<xsl:variable name="this-concept" select="../preceding-sibling::*[1]/@ch:key"/>
	<xsl:if test="not(//ch:gl-entry/ch:vcn[@ch:key=$this])">
		<ch:message>
			<ch:msg-code>
				<xsl:text>VAL-011:</xsl:text>
			</ch:msg-code>
			<ch:msg>
				<xsl:text>Error: Glossary entry for verb concept '</xsl:text>
				<xsl:value-of select="$this-concept"/>
				<xsl:text>' has explanation labeled "See" with value '</xsl:text>
				<xsl:value-of select="$this"/>
				<xsl:text>', but that verb concept is not declared.</xsl:text>					
			</ch:msg>
		</ch:message>								
	</xsl:if>
</xsl:template>

<xsl:template mode="val-012" match="*">
<xsl:variable name="this">
	<xsl:value-of select="@ch:key"/>
</xsl:variable>
<xsl:variable name="this-concept" select="../preceding-sibling::*[1]/@ch:key"/>
	<xsl:if test="not(//ch:gl-entry/ch:vcn[@ch:key=$this])">
		<ch:message>
			<ch:msg-code>
				<xsl:text>VAL-012:</xsl:text>
			</ch:msg-code>
			<ch:msg>
				<xsl:text>Error: Glossary entry for concept '</xsl:text>
				<xsl:value-of select="$this"/>
				<xsl:text>' has unmarked or wrongly marked text.</xsl:text>				
			</ch:msg>
		</ch:message>									
	</xsl:if>
</xsl:template>

</xsl:stylesheet>
